<!-- ko foreach: warnings -->
<p><strong data-bind="text: $root.warningText($data)"></strong></p>
<p class="firmware_check_warning" data-bind="class: $root.cssClass($data)">
    <span data-bind="text: message"></span><br>
    <a target="_blank" rel="noreferrer noopener" data-bind="attr: {href: url}">{{ _('Learn more...') }}</a>
</p>
<!-- /ko -->
